import { ClientCookieManager } from "./clientCookieManager";
import type { Language } from "../constants/lang";
import type { RecordCard, AbyssBattle, GenshinUserData, RealTimeNote, CharacterData, Diary } from "../interface";
export declare class Client {
    private options;
    private cookieManager;
    /**
     * @param {ClientCookieManager} cookieManager - The cookie manager to use.
     * @param {Object} options - The options to use.
     */
    constructor(options: {
        language: Language | Language.EnglishUS;
        cookieManager?: ClientCookieManager;
    });
    /**
     * @description Login for the client.
     * @param {object} options - The options to use.
     */
    login(options: {
        ltuid: string;
        ltoken: string;
    }): void;
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    getAbyssBattle(uid: string, previous?: boolean): Promise<AbyssBattle>;
    /**
     * @param {string} uid - HoYolab uid.
     */
    getGameRecordCard(uid: string): Promise<RecordCard>;
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    getGenshinUser(uid: string): Promise<GenshinUserData>;
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    getRealTimeNotes(uid: string): Promise<RealTimeNote>;
    getCharacter(uid: string): Promise<CharacterData>;
    getTravelDiary(uid: string): Promise<Diary>;
}
