"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const index_1 = require("../index");
const clientCookieManager_1 = require("./clientCookieManager");
class Client {
    /**
     * @param {ClientCookieManager} cookieManager - The cookie manager to use.
     * @param {Object} options - The options to use.
     */
    constructor(options) {
        Object.defineProperty(this, "options", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cookieManager", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new clientCookieManager_1.ClientCookieManager()
        });
        this.options = options;
        this.cookieManager = options.cookieManager || new clientCookieManager_1.ClientCookieManager();
    }
    /**
     * @description Login for the client.
     * @param {object} options - The options to use.
     */
    login(options) {
        this.cookieManager.set(options.ltoken, options.ltuid);
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getAbyssBattle(uid, previous) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.SpiralAbyss().get(uid, language, cookie, previous);
        return res;
    }
    /**
     * @param {string} uid - HoYolab uid.
     */
    async getGameRecordCard(uid) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.GameRecordCard().get(uid, language, cookie);
        return res;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getGenshinUser(uid) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.GenshinUser().get(uid, language, cookie);
        return res;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getRealTimeNotes(uid) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.RealTimeNotes().get(uid, language, cookie);
        return res;
    }
    async getCharacter(uid) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.Charcters().get(uid, language, cookie);
        return res;
    }
    async getTravelDiary(uid) {
        if (!this.cookieManager.get().ltoken)
            throw new Error("You need to login first.");
        const cookie = this.cookieManager.get().cookie;
        const { language } = this.options;
        const res = new index_1.TravelerDiary().get(uid, language, cookie);
        return res;
    }
}
exports.Client = Client;
