"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DailyRewards = void 0;
const request_1 = require("../utils/request");
const error_1 = require("../utils/error");
class DailyRewards {
    /**
       * @description Get the daily rewards details
       * @param {string} cookie The cookie to set
       * @param {Language} language The language to set
       * @param {number} day get the day's rewards
       */
    async getDayReward(day, language, cookie) {
        const instance = new request_1.request({
            type: request_1.urlOption.dailyrewards,
        });
        instance.setLanguage(language);
        const res = await instance.get("home", {
            "Cookie": cookie,
        }, {
            "lang": language,
            "act_id": "e202102251931481",
        });
        if (res.retcode === 0) {
            const { data } = res;
            return data.awards[day - 1];
        }
        throw new error_1.APIError(res.message, res.retcode);
    }
    /**
     *
     * @description Claim the daily rewards
     * @param {Language} language The language to set
     * @param {string} cookie The cookie to set
     */
    async claim(language, cookie) {
        const instance = new request_1.request({
            type: request_1.urlOption.dailyrewards,
            withUA: true,
        });
        const res = await instance.post("sign", {
            "Cookie": cookie,
            "Content-Type": "application/json",
        }, {
            "act_id": "e202102251931481",
        }, {
            "lang": language,
        });
        if (res.retcode === -5003) {
            return {
                status: "Already claimed",
                code: -5003,
            };
        }
        if (res.data.code === "ok" && res.retcode === 0) {
            return {
                status: "success",
                code: 0,
            };
        }
        throw new error_1.APIError(res.message, res.retcode);
    }
}
exports.DailyRewards = DailyRewards;
