"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenshinUser = void 0;
const request_1 = require("../utils/request");
const getServer_1 = require("../utils/getServer");
const error_1 = require("../utils/error");
const clientCache_1 = require("../client/clientCache");
class GenshinUser {
    constructor() {
        Object.defineProperty(this, "cache", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.cache = new clientCache_1.ClientCache();
    }
    /**
       * @param {string} uid The uid to set
       * @param {Language} language The language to set
       * @param {string} cookie The cookie to set
       */
    async get(uid, language, cookie) {
        const instance = new request_1.request({
            withDS: true,
        });
        instance.setLanguage(language);
        const res = await instance.get("index", {
            "x-rpc-client_type": "4",
            "x-rpc-app_version": "1.5.0",
            "Cookie": cookie,
        }, {
            "server": (0, getServer_1.checkServerRegion)(uid),
            "role_id": uid,
        });
        if (res.retcode === 0) {
            const { data } = res;
            this.cache.set(`${uid}-genshinUser`, data);
            return data;
        }
        throw new error_1.APIError(res.message, res.retcode);
    }
}
exports.GenshinUser = GenshinUser;
