"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TravelerDiary = void 0;
const request_1 = require("../utils/request");
const getServer_1 = require("../utils/getServer");
const error_1 = require("../utils/error");
const clientCache_1 = require("../client/clientCache");
class TravelerDiary {
    constructor() {
        Object.defineProperty(this, "cache", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.cache = new clientCache_1.ClientCache();
    }
    /**
       * @param {string} uid The uid to set
       * @param {Language} language The language to set
       * @param {string} cookie The cookie to set
       */
    async get(uid, language, cookie) {
        const instance = new request_1.request({
            withDS: true,
            type: request_1.urlOption.diary
        });
        const res = await instance.get("month_info", {
            "Cookie": cookie,
        }, {
            "server": (0, getServer_1.checkServerRegion)(uid),
            "uid": uid,
            "lang": language,
        });
        if (res.retcode === 0) {
            const { data } = res;
            this.cache.set(`${uid}-diary`, data);
            return data;
        }
        throw new error_1.APIError(res.message, res.retcode);
    }
    async getMonth(uid, month, language, cookie) {
        const instance = new request_1.request({
            withDS: true,
            type: request_1.urlOption.diary
        });
        const res = await instance.get("month_info", {
            "Cookie": cookie,
        }, {
            "server": (0, getServer_1.checkServerRegion)(uid),
            "uid": uid,
            "lang": language,
            "month": month,
        });
        if (res.retcode === 0) {
            const { data } = res;
            this.cache.set(`${uid}-${month}-diary`, data);
            return data;
        }
        throw new error_1.APIError(res.message, res.retcode);
    }
}
exports.TravelerDiary = TravelerDiary;
